@@ -6,7 +6,7 @@
 ;; Maintainer: Protesilaos Stavrou General Issues <~protesilaos/general-issues@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/substitute
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/general-issues
-;; Version: 0.1.5
+;; Version: 0.1.6
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -40,22 +40,29 @@
   "Efficiently replace targets in the buffer or context."
   :group 'editing)
 
-(defcustom substitute-highlight nil
+(defcustom substitute-highlight t
   "If non-nil, highlight target during prompt for its substitute.
 
 If nil, do not highlight anything: just prompt for a substitute.
 
 At any rate, always specify at the minibuffer prompt the target
 of the substitution."
+  :package-version '(substitute . "0.2.0")
   :group 'substitute
   :type 'boolean)
 
-(defcustom substitute-post-replace-hook nil
+(define-obsolete-variable-alias
+  'substitute-post-replace-hook
+  'substitute-post-replace-functions
+  "0.2.0")
+
+(defcustom substitute-post-replace-functions nil
   "Special hook to run after a substitution command.
 Every function is called with four arguments: TARGET, SUB, COUNT,
 and SCOPE.
 
 For a reference function, see `substitute-report-operation'."
+  :package-version '(substitute . "0.2.0")
   :group 'substitute
   :type 'hook)
 
@@ -106,11 +113,11 @@ and related."
   "Prompt for string while referencing TARGET and SCOPE."
   (let ((pretty-target (substitute--prettify-target-description target)))
     (substitute--collect-targets target scope)
-    (read-string
+    (read-from-minibuffer
      (format "Substitute `%s' %s with: "
              (propertize pretty-target 'face 'error)
              (substitute--scope-description scope))
-     nil
+     nil nil nil
      'substitute--history
      pretty-target)))
 
@@ -186,7 +193,7 @@ Each entry is a list of the symbol and its buffer positions.")
       (save-restriction
         (substitute--setup-scope target scope)
         (while (funcall search-fn target nil t)
-          (push (list (match-string-no-properties 0)
+          (push (list (regexp-quote (match-string-no-properties 0))
                       (match-beginning 0)
                       (match-end 0))
                 substitute--last-matches))))
@@ -249,7 +256,7 @@ target at point.
 Report a `user-error' if no target is found."
   (cond
    ((region-active-p)
-    (buffer-substring-no-properties (region-beginning) (region-end)))
+    (regexp-quote (buffer-substring-no-properties (region-beginning) (region-end))))
    (t
     (if-let ((thing (thing-at-point 'symbol t)))
         (format "\\_<%s\\_>" thing)
